@@ -1,4 +1,5 @@
-from monaco import MCCase, MCEnums, MCSim, MCVal, MCVar, MCVarStat
+# flake8: noqa
+from monaco import mc_case, mc_enums, mc_sim, mc_val, mc_var, mc_varstat
 from monaco import gaussian_statistics, order_statistics, integration_statistics
 from monaco import helper_functions, mc_sampling
 from monaco import mc_plot, mc_multi_plot
