@@ -1,29 +1,35 @@
 # helper_functions.py
+from __future__ import annotations
 
 from operator import itemgetter
 from tqdm import tqdm
 import numpy as np
-import pandas as pd
-from typing import Callable, Any, Union, Sequence, Iterable, Sized
+from typing import Callable, Any, Sequence, Iterable, Sized
 from time import time
 from functools import wraps
 from hashlib import sha512
 import warnings
 
+# Optional imports
+try:
+    import pandas as pd
+except ImportError:
+    pd = None
+
 
 def next_power_of_2(x : int) -> int:
     """
     Returns the next power of two greater than or equal to the input.
-    
+
     Parameters
     ----------
     x : int
         The input number.
-    
+
     Returns
     -------
-    _ : int
-        The next power of two, _ >= x.
+    nextpow2 : int
+        The next power of two, nextpow2 >= x.
     """
     if x <= 0:
         return 0
@@ -36,32 +42,55 @@ def hash_str_repeatable(s : str) -> int:
     By default, string hashing in python is randomized. This function returns a
     repeatable non-randomized hash for strings.
     See: https://docs.python.org/3/using/cmdline.html#cmdoption-R
-    
+
     Parameters
     ----------
     s : str
         The string to hash.
-    
+
     Returns
     -------
-    _ : int
+    s_hash : int
         The hash of str.
     """
     return int(sha512(s.encode('utf-8')).hexdigest(), 16)
 
 
+def hashable_val(val : Any) -> Any:
+    """
+    For `nummap`s and `valmap`s, we need to use values as keys in a dictionary.
+    This will return the string representation of a value if that value is not
+    hashable.
+
+    Parameters
+    ----------
+    val : Any
+        The value to hash.
+
+    Returns
+    -------
+    hashable_val : Any
+        A hashable representation of the val.
+    """
+    try:
+        hash(val)
+        return val
+    except TypeError:
+        return str(val)
+
+
 def is_num(val : Any) -> bool:
     """
     Type checking function to see if the input is a number.
-    
+
     Parameters
     ----------
     val : Any
         The value to check.
-    
+
     Returns
     -------
-    _ : bool
+    isnum : bool
         Returns True if the input is a number, False otherwise.
     """
     if isinstance(val, bool) or isinstance(val, str):
@@ -78,15 +107,15 @@ def is_num(val : Any) -> bool:
 def length(x : Any) -> int:
     """
     Genericized length function that works on scalars (which have length 1).
-    
+
     Parameters
     ----------
     x : Any
         The value to check.
-    
+
     Returns
     -------
-    _ : int
+    x_len : int
         The length of the input.
     """
     if isinstance(x, Sized):
@@ -97,54 +126,54 @@ def length(x : Any) -> int:
         return None
 
 
-def get_tuple(x : Any) -> tuple:
+def get_list(x : Any) -> list[Any]:
     """
-    Converts the input to an iterable tuple.
-    
+    Converts the input to an iterable list.
+
     Parameters
     ----------
     x : Any
         The object to convert.
-    
+
     Returns
     -------
-    _ : tuple
-        A tuple conversion of the input.
+    x_list : list
+        A list conversion of the input.
     """
     if x is None:
-        return tuple()
-    elif isinstance(x, pd.DataFrame):
-        return (x,)
+        return list()
+    elif pd and isinstance(x, pd.DataFrame):
+        return [x, ]
     elif isinstance(x, Iterable):
-        return tuple(x)
+        return list(x)
     else:
-        return (x,)
+        return [x, ]
 
 
-def slice_by_index(sequence : Sequence, 
-                   indices : Union[int, Iterable]
+def slice_by_index(sequence : Sequence[Any],
+                   indices  : int | Iterable[int],
                    ) -> list:
     """
     Returns a slice of a sequence at the specified indices.
-    
+
     Parameters
     ----------
     sequence : Sequence
         The sequence to slice.
-    indices : {int, Iterable}
+    indices : int | Iterable
         The indices to slice at.
-    
+
     Returns
     -------
-    _ : list
+    slice : list
         A list representing the values of the input sequence at the specified
         indices.
     """
-    indices_tuple = get_tuple(indices)
-    if sequence is None or indices_tuple == tuple():
+    indices_list = get_list(indices)
+    if sequence is None or indices_list == list():
         return []
-    items = itemgetter(*indices_tuple)(sequence)
-    if len(indices_tuple) == 1:
+    items = itemgetter(*indices_list)(sequence)
+    if len(indices_list) == 1:
         return [items]
     return list(items)
 
@@ -152,7 +181,7 @@ def slice_by_index(sequence : Sequence,
 def vprint(verbose : bool, *args, **kwargs) -> None:
     """
     Print only if verbose is True.
-    
+
     Parameters
     ----------
     verbose : bool
@@ -174,7 +203,7 @@ def warn_short_format(message, category, filename, lineno, file=None, line=None)
 def vwarn(verbose : bool, *args, **kwargs) -> None:
     """
     Warn only if verbose is True.
-    
+
     Parameters
     ----------
     verbose : bool
@@ -184,7 +213,7 @@ def vwarn(verbose : bool, *args, **kwargs) -> None:
     """
     if verbose:
         warn_default_format = warnings.formatwarning
-        warnings.formatwarning = warn_short_format # type: ignore
+        warnings.formatwarning = warn_short_format  # type: ignore
         warnings.warn(*args, **kwargs)
         warnings.formatwarning = warn_default_format
 
@@ -192,7 +221,7 @@ def vwarn(verbose : bool, *args, **kwargs) -> None:
 def vwrite(verbose : bool, *args, **kwargs) -> None:
     """
     Perform a tqdm.write() only if verbose is True.
-    
+
     Parameters
     ----------
     verbose : bool
@@ -207,7 +236,7 @@ def vwrite(verbose : bool, *args, **kwargs) -> None:
 def timeit(fcn : Callable):
     """
     Function decorator to print out the function runtime in milliseconds.
-    
+
     Parameters
     ----------
     fcn : Callable
@@ -223,7 +252,7 @@ def timeit(fcn : Callable):
     return timed
 
 
-def empty_list():
+def empty_list() -> list:
     """
     Sentinel for default arguments being an empty list.
 
@@ -232,5 +261,32 @@ def empty_list():
     empty_list : list
         An empty list.
     """
-    empty_list = []
-    return empty_list
\ No newline at end of file
+    return []
+
+
+def flatten(nested_x : Iterable[Any]) -> list[Any]:
+    """
+    Flattens a nested interable into a list with all nested items.
+
+    Parameters
+    ----------
+    nested_x : Iterable
+        Nested iterable.
+
+    Returns
+    -------
+    flattened_x : list
+        The nested iterable flattened into a list.
+    """
+    def flatten_generator(x) -> Any:
+        if isinstance(x, (str, bytes)):
+            yield x
+        else:
+            for element in x:
+                try:
+                    yield from flatten(element)
+                except TypeError:
+                    yield element
+
+    flattened_x = list(flatten_generator(nested_x))
+    return flattened_x
